@@ -4,11 +4,11 @@ from collections import OrderedDict
 
 def get_image_hash(image):
     """
-    Get the hash value of the image
+    Get the hash value of the `image`.
 
     Args:
         image (np.ndarray): image in uint8, range [0..255]
-    Return:
+    Returns:
         image_hash (str): the hexadecimal hashed value for the image
     """
     return sha256(image).hexdigest()
@@ -16,11 +16,11 @@ def get_image_hash(image):
 
 def get_styling_config_hash(styling_config):
     """
-    Get the hash value of the styling config
+    Get the hash value of the `styling_config`.
 
     Args:
         styling_config (Bunch): an instance of styling configurations
-    Return:
+    Returns:
         styling_config_hash (str): the hexadecimal hashed value for the config
     """
     ordered_config = OrderedDict(sorted(styling_config.items()))
