@@ -4,21 +4,24 @@ import numpy as np
 
 def load_image(image_path):
     """
-    Load an RGB image from disk and check if it was loaded correctly
+    Load an RGB image from disk and check if it was loaded correctly.
 
     Args:
         image_path (str): path to the image
-    Return
+    Returns:
         image (np.ndarray): 3-channeled image
+    Raises:
+        FileNotFoundError: if the image path does not exist
     """
     image = cv2.imread(image_path, cv2.IMREAD_COLOR)
-    assert image is not None, f'Image {image_path} not found'
+    if image is None:
+        raise FileNotFoundError(f'Image "{image_path}" was not found')
     return cv2.cvtColor(image, cv2.COLOR_BGR2RGB)
 
 
 def save_image(image_path, image):
     """
-    Save an RGB image to disk
+    Save an RGB image to disk.
 
     Args:
         image_path (str): path to the file to save
@@ -28,13 +31,27 @@ def save_image(image_path, image):
     cv2.imwrite(image_path, image)
 
 
+def load_mask(mask_path):
+    """
+    Load a grayscale mask from disk and check if it was loaded correctly.
+
+    Args:
+        mask_path (str): path to the mask
+    Returns:
+        mask (np.ndarray): single channel image
+    """
+    mask = cv2.imread(mask_path, cv2.IMREAD_GRAYSCALE)
+    assert mask is not None, f'Mask "{mask_path}" was not found'
+    return mask
+
+
 def image2tensor(image):
     """
-    Convert from image space to styling space by rescaling values
+    Convert from image space to styling space by rescaling values.
 
     Args:
         image (np.ndarray): image in uint8, range [0..255]
-    Return:
+    Returns:
         tensor (np.ndarray): tensor in float32, range [-1..1]
     """
     return image.astype(np.float32) / 127.5 - 1.0
@@ -42,11 +59,11 @@ def image2tensor(image):
 
 def tensor2image(tensor):
     """
-    Convert from styling space to image space by rescaling values
+    Convert from styling space to image space by rescaling values.
 
     Args:
         tensor (np.ndarray): tensor in float32, range [-1..1]
-    Return:
+    Returns:
         image (np.ndarray): image in uint8, range [0..255]
     """
     return ((tensor + 1.0) * 127.5).astype(np.uint8)
